@@ -3,9 +3,9 @@ package Sah::Schemas::Re;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-09-03'; # DATE
+our $DATE = '2023-09-05'; # DATE
 our $DIST = 'Sah-Schemas-Re'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 1;
 # ABSTRACT: Various regular-expression schemas
@@ -22,7 +22,7 @@ Sah::Schemas::Re - Various regular-expression schemas
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schemas::Re (from Perl distribution Sah-Schemas-Re), released on 2023-09-03.
+This document describes version 0.003 of Sah::Schemas::Re (from Perl distribution Sah-Schemas-Re), released on 2023-09-05.
 
 =head1 SAH SCHEMAS
 
@@ -43,6 +43,33 @@ Otherwise, your string will be C<quotemeta()>-ed first then compiled to Regexp
 object. This means in the second case you cannot specify metacharacters.
 
 
+=item * L<re_or_code_from_str|Sah::Schema::re_or_code_from_str>
+
+Regex (convertable from string of the form `E<sol>...E<sol>`) or coderef (convertable from string of the form `sub { ... }`).
+
+Either Regexp object or coderef is accepted.
+
+Coercion from string is available for Regexp If string is of the form of C</.../>
+or C<qr(...)>, then it will be compiled into a Regexp object. If the regex
+pattern inside C</.../> or C<qr(...)> is invalid, value will be rejected.
+Currently, unlike in normal Perl, for the C<qr(...)> form, only parentheses C<(>
+and C<)> are allowed as the delimiter. Currently modifiers C<i>, C<m>, and C<s>
+after the second C</> are allowed.
+
+Coercion from string is available for coderef if string matches the regex
+C<qr/\Asub\s*\{.*\}\z/s>, then it will be eval'ed into a coderef. If the code
+fails to compile, the value will be rejected. Note that this means you accept
+arbitrary code from the user to execute! Please make sure first and foremost
+that this is acceptable in your case. Currently string is eval'ed in the C<main>
+package, without C<use strict> or C<use warnings>.
+
+Coercion from string to regex literal is also available for other forms of
+string.
+
+This schema is handy if you want to accept regex or coderef from the
+command-line.
+
+
 =back
 
 =head1 HOMEPAGE
